from .color import color

class presets:
    # --- Grayscale ---
    white = color(255, 255, 255)
    snow = color(255, 250, 250)
    honey_dew = color(240, 255, 240)
    mint_cream = color(245, 255, 250)
    azure = color(240, 255, 255)
    alice_blue = color(240, 248, 255)
    ghost_white = color(248, 248, 255)
    white_smoke = color(245, 245, 245)
    gainsboro = color(220, 220, 220)
    light_gray = color(211, 211, 211)
    silver = color(192, 192, 192)
    dark_gray = color(169, 169, 169)
    gray = color(128, 128, 128)
    dim_gray = color(105, 105, 105)
    slate_gray = color(112, 128, 144)
    light_slate_gray = color(119, 136, 153)
    dark_slate_gray = color(47, 79, 79)
    black = color(0, 0, 0)
    
    # --- Red Shades ---
    red = color(255, 0, 0)
    dark_red = color(139, 0, 0)
    fire_brick = color(178, 34, 34)
    crimson = color(220, 20, 60)
    indian_red = color(205, 92, 92)
    light_coral = color(240, 128, 128)
    salmon = color(250, 128, 114)
    dark_salmon = color(233, 150, 122)
    light_salmon = color(255, 160, 122)
    tomato = color(255, 99, 71)
    orange_red = color(255, 69, 0)
    brick_red = color(151, 0, 0)
    bright_red = color(196, 40, 28)
    ruby = color(224, 17, 95)
    scarlet = color(255, 36, 0)
    maroon = color(128, 0, 0)
    burgundy = color(128, 0, 32)
    radical_red = color(255, 50, 100)

    # --- Pink Shades ---
    pink = color(255, 192, 203)
    light_pink = color(255, 182, 193)
    hot_pink = color(255, 105, 180)
    deep_pink = color(255, 20, 147)
    pale_violet_red = color(219, 112, 147)
    medium_violet_red = color(199, 21, 133)
    lavender_blush = color(255, 240, 245)
    misty_rose = color(255, 228, 225)
    thistle = color(216, 191, 216)
    fuchsia = color(255, 0, 255)

    # --- Orange Shades ---
    orange = color(255, 165, 0)
    dark_orange = color(255, 140, 0)
    coral = color(255, 127, 80)
    sandy_brown = color(244, 164, 96)
    dark_goldenrod = color(184, 134, 11)
    goldenrod = color(218, 165, 32)
    light_goldenrod_yellow = color(250, 250, 210)
    burly_wood = color(222, 184, 135)
    tan = color(210, 180, 140)
    peach_puff = color(255, 218, 185)
    navajo_white = color(255, 222, 173)
    moccasin = color(255, 228, 181)
    papaya_whip = color(255, 239, 213)
    blanched_almond = color(255, 235, 205)
    antique_white = color(250, 235, 215)
    bright_orange = color(255, 148, 0)
    persimmon = color(236, 88, 0)

    # --- Yellow Shades ---
    yellow = color(255, 255, 0)
    light_yellow = color(255, 255, 224)
    lemon_chiffon = color(255, 250, 205)
    pale_goldenrod = color(238, 232, 170)
    khaki = color(240, 230, 140)
    dark_khaki = color(189, 183, 107)
    gold = color(255, 215, 0)
    olive = color(128, 128, 0)
    yellow_green = color(154, 205, 50)
    bright_yellow = color(245, 205, 48)
    canary_yellow = color(255, 255, 153)

    # --- Green Shades ---
    green = color(0, 128, 0)
    lime = color(0, 255, 0)
    dark_green = color(0, 100, 0)
    forest_green = color(34, 139, 34)
    sea_green = color(46, 139, 87)
    medium_sea_green = color(60, 179, 113)
    light_sea_green = color(32, 178, 170)
    pale_green = color(152, 251, 152)
    light_green = color(144, 238, 144)
    medium_spring_green = color(0, 250, 154)
    spring_green = color(0, 255, 127)
    lime_green = color(50, 205, 50)
    chartreuse = color(127, 255, 0)
    lawn_green = color(124, 252, 0)
    green_yellow = color(173, 255, 47)
    olive_drab = color(107, 142, 35)
    dark_olive_green = color(85, 107, 47)
    teal = color(0, 128, 128)
    dark_cyan = color(0, 139, 139)
    aquamarine = color(127, 255, 212)
    medium_aquamarine = color(102, 205, 170)
    pale_turquoise = color(175, 238, 238)
    medium_turquoise = color(72, 209, 204)
    turquoise = color(64, 224, 208)
    dark_turquoise = color(0, 206, 209)
    bright_green = color(0, 217, 58)
    emerald_green = color(80, 200, 120)

    # --- Blue Shades ---
    blue = color(0, 0, 255)
    dark_blue = color(0, 0, 139)
    medium_blue = color(0, 0, 205)
    midnight_blue = color(25, 25, 112)
    navy = color(0, 0, 128)
    royal_blue = color(65, 105, 225)
    cornflower_blue = color(100, 149, 237)
    dodger_blue = color(30, 144, 255)
    deep_sky_blue = color(0, 191, 255)
    light_sky_blue = color(135, 206, 250)
    sky_blue = color(135, 206, 235)
    steel_blue = color(70, 130, 180)
    light_steel_blue = color(176, 196, 222)
    powder_blue = color(176, 224, 230)
    cadet_blue = color(95, 158, 160)
    cyan = color(0, 255, 255)
    light_cyan = color(224, 255, 255)
    aqua = color(0, 255, 255)
    cerulean = color(0, 123, 167)
    cobalt_blue = color(0, 71, 171)
    bright_blue = color(13, 105, 172)
    ocean_blue = color(0, 119, 190)

    # --- Purple/Violet Shades ---
    purple = color(128, 0, 128)
    violet = color(238, 130, 238)
    dark_magenta = color(139, 0, 139)
    medium_orchid = color(186, 85, 211)
    orchid = color(218, 112, 214)
    plum = color(221, 160, 221)
    medium_purple = color(147, 112, 219)
    blue_violet = color(138, 43, 226)
    dark_violet = color(148, 0, 211)
    dark_orchid = color(153, 50, 204)
    rebecca_purple = color(102, 51, 153)
    indigo = color(75, 0, 130)
    amethyst = color(153, 102, 204)
    lavender = color(230, 230, 250)
    royal_purple = color(98, 37, 209)
    electric_violet = color(143, 0, 255)
    heliotrope = color(223, 115, 255)

    # --- Brown Shades ---
    brown = color(165, 42, 42)
    dark_brown = color(101, 67, 33)
    saddle_brown = color(139, 69, 19)
    sienna = color(160, 82, 45)
    chocolate = color(210, 105, 30)
    peru = color(205, 133, 63)
    rosy_brown = color(188, 143, 143)
    wheat = color(245, 222, 179)
    bisque = color(255, 228, 196)

    # --- Other Hues ---
    magenta = color(255, 0, 255)

    # --- Pastel colors ---
    pastel_red = color(255, 204, 204)
    pastel_pink = color(255, 220, 229)
    pastel_orange = color(255, 229, 204)
    pastel_yellow = color(255, 255, 204)
    pastel_green = color(204, 255, 204)
    pastel_mint = color(189, 252, 201)
    pastel_blue = color(204, 204, 255)
    pastel_cyan = color(204, 255, 255)
    pastel_lavender = color(230, 230, 250)
    pastel_purple = color(229, 204, 255)
    pastel_violet = color(200, 162, 200)
    pastel_brown = color(210, 180, 140)
    pastel_grey = color(207, 207, 207)

    # --- Vibrant/Bright colors ---
    vibrant_red = color(255, 40, 40)
    vibrant_orange = color(255, 110, 0)
    vibrant_yellow = color(255, 255, 50)
    vibrant_green = color(0, 255, 50)
    vibrant_blue = color(0, 80, 255)
    vibrant_purple = color(180, 0, 255)
    vibrant_pink = color(255, 0, 150)
    vibrant_cyan = color(0, 255, 255)
    vibrant_magenta = color(255, 0, 255)

    # --- Deep/Rich colors ---
    deep_red = color(153, 0, 0)
    deep_orange = color(204, 85, 0)
    deep_yellow = color(204, 204, 0)
    deep_green = color(0, 102, 0)
    deep_blue = color(0, 0, 153)
    deep_purple = color(102, 0, 102)
    deep_pink = color(204, 0, 102)
    deep_teal = color(0, 85, 85)
    deep_maroon = color(102, 0, 0)